"""pygrowthmodels - A compilation of nonlinear growth models"""

from pygrowthmodels.blumberg import blumberg
from pygrowthmodels.blumberg import blumberg_inverse
from pygrowthmodels.brody import brody
from pygrowthmodels.brody import brody_inverse
from pygrowthmodels.chapman_richards import chapman_richards
from pygrowthmodels.chapman_richards import chapman_richards_inverse
from pygrowthmodels.gompertz import gompertz
from pygrowthmodels.gompertz import gompertz_inverse
from pygrowthmodels.janoschek import janoschek
from pygrowthmodels.janoschek import janoschek_inverse
from pygrowthmodels.logistic import generalised_logistic
from pygrowthmodels.logistic import generalised_logistic_inverse
from pygrowthmodels.logistic import logistic
from pygrowthmodels.logistic import logistic_inverse
from pygrowthmodels.mitcherlich import mitcherlich
from pygrowthmodels.mitcherlich import mitcherlich_inverse
from pygrowthmodels.mmf import mmf
from pygrowthmodels.mmf import mmf_inverse
from pygrowthmodels.monomolecular import monomolecular
from pygrowthmodels.monomolecular import monomolecular_inverse
from pygrowthmodels.negative_exponential import negative_exponential
from pygrowthmodels.negative_exponential import negative_exponential_inverse
from pygrowthmodels.richard import generalised_richard
from pygrowthmodels.richard import generalised_richard_inverse
from pygrowthmodels.richard import richard
from pygrowthmodels.richard import richard_inverse
from pygrowthmodels.schnute import schnute
from pygrowthmodels.schnute import schnute_inverse
from pygrowthmodels.stannard import stannard
from pygrowthmodels.stannard import stannard_inverse
from pygrowthmodels.vonbertalanffy import vonbertalanffy
from pygrowthmodels.vonbertalanffy import vonbertalanffy_inverse
from pygrowthmodels.weibull import weibull
from pygrowthmodels.weibull import weibull_inverse

__version__ = '0.0.1'
__author__ = u'Daniel Rodríguez Pérez <daniel.rodriguez.perez@gmail.com>'
__all__ = []
